@@ -35,6 +35,6 @@ class MiApi:
         '''
 
         api = request.Api(self.ip, self.port, self.usr, self.pwd)
-        request = api.request(program, transaction, **kwargs)
+        result = api.request(program, transaction, **kwargs)
 
-        return parser.parse_mi_xml(request.content)
+        return parser.parse_mi_xml(result.content)
